Tord
====

Asynchronous Websocket + Pubsub based web framework built over Tornado, Redis, ZMQ, SockJS

Goals:
------

- Micro Framework
- REST API over HTTP and Websocket (over same TCP port)
- Template support
- Static serving support
- PubSub support using Redis or ZMQ
- Asynchronous + Tornado event loop

See [example](https://github.com/abhinavsingh/tord/tree/master/example) for usage and documentation.
